@@ -14,9 +14,11 @@ from botocore.auth import SigV4Auth
 from botocore.awsrequest import AWSRequest
 from gremlin_python.driver import client
 from neo4j import GraphDatabase
-from tornado import httpclient
+import nest_asyncio
 
-import graph_notebook.neptune.gremlin.graphsonV3d0_MapType_objectify_patch  # noqa F401
+# This patch is no longer needed when graph_notebook is using the a Gremlin Python
+# client >= 3.5.0 as the HashableDict is now part of that client driver.
+# import graph_notebook.neptune.gremlin.graphsonV3d0_MapType_objectify_patch  # noqa F401
 
 DEFAULT_SPARQL_CONTENT_TYPE = 'application/x-www-form-urlencoded'
 DEFAULT_PORT = 8182
@@ -120,8 +122,16 @@ class Client(object):
             else:
                 data['explain'] = explain
 
-        sparql_path = path if path != '' else self.sparql_path
-        uri = f'{self._http_protocol}://{self.host}:{self.port}/{sparql_path}'
+        if path != '':
+            sparql_path = f'/{path}'
+        elif self.sparql_path != '':
+            sparql_path = f'/{self.sparql_path}'
+        elif "neptune.amazonaws.com" in self.host:
+            sparql_path = f'/{SPARQL_ACTION}'
+        else:
+            sparql_path = ''
+
+        uri = f'{self._http_protocol}://{self.host}:{self.port}{sparql_path}'
         req = self._prepare_request('POST', uri, data=data, headers=headers)
         res = self._http_session.send(req)
         return res
@@ -158,12 +168,13 @@ class Client(object):
         return self._query_status('sparql', query_id=query_id, silent=silent, cancelQuery=True)
 
     def get_gremlin_connection(self) -> client.Client:
+        nest_asyncio.apply()
+
         uri = f'{self._http_protocol}://{self.host}:{self.port}/gremlin'
         request = self._prepare_request('GET', uri)
 
         ws_url = f'{self._ws_protocol}://{self.host}:{self.port}/gremlin'
-        ws_request = httpclient.HTTPRequest(ws_url, headers=dict(request.headers))
-        return client.Client(ws_request, 'g')
+        return client.Client(ws_url, 'g', headers=dict(request.headers))
 
     def gremlin_query(self, query, bindings=None):
         c = self.get_gremlin_connection()
@@ -392,6 +403,7 @@ class Client(object):
         return res
 
     def modeltraining_start(self, data_processing_job_id: str, train_model_s3_location: str,
+                            max_hpo_number_of_training_jobs: int, max_hpo_parallel_training_jobs: int,
                             **kwargs) -> requests.Response:
         """
         for a full list of supported parameters, see:
@@ -399,7 +411,9 @@ class Client(object):
         """
         data = {
             'dataProcessingJobId': data_processing_job_id,
-            'trainModelS3Location': train_model_s3_location
+            'trainModelS3Location': train_model_s3_location,
+            'maxHPONumberOfTrainingJobs': max_hpo_number_of_training_jobs,
+            'maxHPOParallelTrainingJobs': max_hpo_parallel_training_jobs
         }
 
         for k, v in kwargs.items():
@@ -444,8 +458,9 @@ class Client(object):
         res = self._http_session.send(req)
         return res
 
-    def modeltransform_create(self, output_s3_location: str, dataprocessing_job_id: str = '', modeltraining_job_id: str = '',
-                              training_job_name: str = '', **kwargs) -> requests.Response:
+    def modeltransform_create(self, output_s3_location: str, dataprocessing_job_id: str = '',
+                              modeltraining_job_id: str = '', training_job_name: str = '',
+                              **kwargs) -> requests.Response:
         logger.debug("modeltransform_create initiated with params:"
                      f"output_s3_location: {output_s3_location}\n"
                      f"dataprocessing_job_id: {dataprocessing_job_id}\n"
@@ -462,7 +477,8 @@ class Client(object):
             data['mlModelTrainingJobId'] = modeltraining_job_id
         else:
             raise ValueError(
-                'Invalid input. Must only specify either dataprocessing_job_id and modeltraining_job_id or only training_job_name')
+                'Invalid input. Must only specify either dataprocessing_job_id and modeltraining_job_id or only '
+                'training_job_name')
 
         for k, v in kwargs.items():
             data[k] = v
@@ -511,10 +527,17 @@ class Client(object):
         res = self._http_session.send(req)
         return res
 
-    def endpoints_create(self, training_job_id: str, **kwargs) -> requests.Response:
-        data = {
-            'mlModelTrainingJobId': training_job_id
-        }
+    def endpoints_create(self, model_training_job_id: str = '', model_transform_job_id: str = '',
+                         **kwargs) -> requests.Response:
+        data = {}
+
+        if model_training_job_id and not model_transform_job_id:
+            data['mlModelTrainingJobId'] = model_training_job_id
+        elif model_transform_job_id and not model_training_job_id:
+            data['mlModelTransformJobId'] = model_transform_job_id
+        else:
+            raise ValueError('Invalid input. Must either specify model_training_job_id or model_transform_job_id, '
+                             'and not both.')
 
         for k, v in kwargs.items():
             data[k] = v
